package util

import (
	"fmt"
	"git.168cad.top/zhengqiuyun/rym-util/exception"
	"math"
	"time"
)

const formatSimple0 = "2006-01-02 15:04:05.000000"
const formatSimple1 = "2006-01-02 15:04:05"
const formatSimple2 = "2006-01-02"
const formatSimple3 = "20060102"
const DayStart = "00:00:00"
const DayEnd = "23:59:59"

func FormatDate(dateTime time.Time) string {
	return dateTime.Format(formatSimple2)
}
func FormatDates(dateTime time.Time) string {
	return dateTime.Format(formatSimple3)
}

func FormatDateTime(dateTime time.Time) string {
	return dateTime.Format(formatSimple1)
}

func FormatDateMillTime(dateTime time.Time) string {
	return dateTime.Format(formatSimple0)
}

func ParseDateStart(date string) time.Time {
	stamp, err := time.ParseInLocation(formatSimple1, date+" 00:00:00", time.Local)
	exception.AssertThrowable(err != nil, "SYSTEM_ERR.TIME_INVALID", fmt.Sprintf("[%s]时间格式错误", date))
	return stamp
}

func ParseDateTime(dateTime string) time.Time {
	stamp, err := time.ParseInLocation(formatSimple1, dateTime, time.Local)
	exception.AssertThrowable(err != nil, "SYSTEM_ERR.TIME_INVALID", fmt.Sprintf("[%s]时间格式错误", dateTime))
	return stamp
}

func ParseDateTimeE(dateTime string, name string) time.Time {
	stamp, err := time.ParseInLocation(formatSimple1, dateTime, time.Local)
	exception.AssertThrowable(err != nil, "SYSTEM_ERR.TIME_INVALID", fmt.Sprintf("%s格式错误", name))
	return stamp
}

func AddDate(date time.Time, d int) time.Time {
	t := (int64)(d * 24 * 60 * 60)
	return Add(date, t)
}

func Add(date time.Time, d int64) time.Time {
	t := date.Unix()
	t += d //增加秒
	return time.Unix(t, 0)
}

func Start(date time.Time) time.Time {
	return time.Date(date.Year(), date.Month(), date.Day(), 0, 0, 0, 0, date.Location()) // 获取当天0点时间 time类型
}

func TimeSubDays(t1, t2 time.Time) int {
	if t1.Location().String() != t2.Location().String() {
		return -1
	}
	hours := t1.Sub(t2).Hours()
	t1y, t1m, t1d := t1.Date()
	t2y, t2m, t2d := t2.Date()
	if t1y == t2y && t1m == t2m && t1d == t2d { //同一天
		return 0
	} else {
		return int(hours/24 + 1)
	}
}

// TimeSubMinute t1比t2多多少分钟，向上取整
func TimeSubMinute(t1, t2 *time.Time) int {
	if t1.Location().String() != t2.Location().String() {
		return -1
	}
	seconds := t1.Sub(*t2).Seconds()
	return int(math.Ceil(seconds / 60)) //向上取整
}

// TimeSubMinuteFloor t1比t2多多少分钟，向上取整
func TimeSubMinuteFloor(t1, t2 *time.Time) int {
	if t1.Location().String() != t2.Location().String() {
		return -1
	}
	seconds := t1.Sub(*t2).Seconds()
	return int(math.Floor(seconds / 60)) //向上取整
}

func MilSecond(time time.Time) int64 {
	return time.UnixNano() / 1e6
}
